@@ -271,7 +271,7 @@ class GwibberAccountManager(object):
           if not new_account:
               self.aw = eval(protocol["name"]).AccountWidget(self.account)
           else:
-              self.aw = eval(protocol["name"]).AccountWidget()
+              self.aw = eval(protocol["name"]).AccountWidget(None, self.ui)
           self.aw.show()
 	except NameError:
           print ("%s not available", protocol["name"])
@@ -280,7 +280,7 @@ class GwibberAccountManager(object):
         if new_account:
             self.account = {}
             self.account["protocol"] = protocol["name"]
-            self.ui.get_object('vbox_create').show()
+            #self.ui.get_object('vbox_create').show()
         self.aw.account = self.account
         self.populate_account_data()
 
@@ -388,4 +388,5 @@ class GwibberAccountManager(object):
         self.account_show(icon=icon)
 
     def on_button_close_clicked(self, widget, data=None):
+        self.gwibber_service.RefreshCreds()
         gtk.main_quit()  
