@@ -43,7 +43,7 @@ class GwibberPosterVBox(gtk.VBox):
     self.input_splitter.add1(self.input)
 
     self.button_send = gtk.Button(_("Send"))
-    self.button_send.connect("clicked", self.on_input_activate)
+    self.button_send.connect("clicked", self.on_button_send_clicked)
     self.message_target = gwibber.gwui.AccountTargetBar(self.stream_model)
     self.message_target.pack_end(self.button_send, False)
 
@@ -63,4 +63,7 @@ class GwibberPosterVBox(gtk.VBox):
     self.service.SendMessage(text)
     w.clear()
 
+  def on_button_send_clicked(self, w):
+    self.service.SendMessage(self.input.get_text())
+    self.input.clear()
 
