@@ -342,7 +342,7 @@ class MessagesMonitor(dbus.service.Object):
       n = util.notify(sender_name, message["text"], image, expire_timeout)
 
 class MapAsync(threading.Thread):
-  def __init__(self, func, iterable, cbsuccess, cbfailure, timeout=120):
+  def __init__(self, func, iterable, cbsuccess, cbfailure, timeout=240):
     threading.Thread.__init__(self)
     self.iterable = iterable
     self.callback = cbsuccess
@@ -355,7 +355,7 @@ class MapAsync(threading.Thread):
   def run(self):
     try:
       pool = multiprocessing.Pool()
-      pool.map_async(self.func, self.iterable, callback=self.callback).get(self.timeout)
+      pool.map_async(self.func, self.iterable, callback=self.callback).get(timeout=self.timeout)
     except Exception as e:
       self.failure(e, traceback.format_exc())
 
