@@ -125,16 +125,14 @@ class Client:
     data = network.Download(url, util.compact(args), post,
         self.account["username"], self.account["password"]).get_json()
 
-    # error is "Could not authenticate you" for failed auth
-    try:
-      if single: return [getattr(self, "_%s" % parse)(data)]
-      if parse: return [getattr(self, "_%s" % parse)(m) for m in data]
-      else: return []
-    except:
-      if data.has_key("error"):
-        if "authenticate" in data["error"]:
-          raise exceptions.GwibberProtocolError("auth", self.account["protocol"], self.account["username"], data["error"])
+    if isinstance(data, dict) and data.get("error", 0):
+      if "authenticate" in data["error"]:
+        raise exceptions.GwibberProtocolError("auth", self.account["protocol"], self.account["username"], data["error"])
 
+    if single: return [getattr(self, "_%s" % parse)(data)]
+    if parse: return [getattr(self, "_%s" % parse)(m) for m in data]
+    else: return []
+      
   def _search(self, **args):
     data = network.Download("%s/api/search.json" % URL_PREFIX, util.compact(args))
     data = data.get_json()["results"]
