@@ -1,4 +1,20 @@
 
+from os.path import join, isdir, realpath
+from os import mkdir
+
+import xdg.BaseDirectory
+
+CACHE_DIR = realpath(join(xdg.BaseDirectory.xdg_cache_home, "gwibber"))
+if not isdir(CACHE_DIR):
+  mkdir(CACHE_DIR)
+
+from os import environ
+if environ.has_key("FB_APP_KEY"):
+  FB_APP_KEY = environ["FB_APP_KEY"]
+else:
+  FB_APP_KEY = "71b85c6d8cb5bbb9f1a3f8bbdcdd4b05"
+
+
 # Gwibber
 MAX_MESSAGE_LENGTH = 140
 
@@ -35,7 +51,7 @@ RETWEET_FORMATS = {
   "service": "{R} @{nick}: {text}",
 }
 
-VERSION_NUMBER = "2.30.0.1"
+VERSION_NUMBER = "2.30.1"
 GCONF_CLIENT_DIR = "/apps/gwibber/client/"
 
 BUG_URL = "https://bugs.launchpad.net/gwibber/+filebug"
@@ -112,6 +128,10 @@ COUCH_VIEW_MESSAGES = {
   "mine": {
     "map": "function(doc) { if(doc.sender.is_me) emit([doc.time], null); }",
   },
+  "max_message_time": {
+      "map": "function(doc) { emit([doc.account, doc.operation], doc.time); }",
+      "reduce": "function(key, value, rereduce) { return Math.max.apply(Math, value); }"
+  },
 }
 
 GWIBBER_OPERATIONS = """
